/*
Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
Copyright (C) 2005- The University of Notre Dame
This software is distributed under a BSD-style license.
See the file COPYING for details.
*/

#ifndef CHIRP_RELI_H
#define CHIRP_RELI_H

#include "chirp_client.h"

#include <sys/types.h>
#include <stdio.h>

struct chirp_file * chirp_reli_open( const char *host, const char *path, INT64_T flags, INT64_T mode, time_t stoptime );
INT64_T chirp_reli_close( struct chirp_file *file, time_t stoptime );
INT64_T chirp_reli_pread( struct chirp_file *file, void *buffer, INT64_T length, INT64_T offset, time_t stoptime );
INT64_T chirp_reli_pwrite( struct chirp_file *file, const void *buffer, INT64_T length, INT64_T offset, time_t stoptime );
INT64_T chirp_reli_fstat( struct chirp_file *file, struct chirp_stat *buf, time_t stoptime );
INT64_T chirp_reli_fstatfs( struct chirp_file *file, struct chirp_statfs *buf, time_t stoptime );
INT64_T chirp_reli_fchown( struct chirp_file *file, INT64_T uid, INT64_T gid, time_t stoptime );
INT64_T chirp_reli_fchmod( struct chirp_file *file, INT64_T mode, time_t stoptime );
INT64_T chirp_reli_ftruncate( struct chirp_file *file, INT64_T length, time_t stoptime );
INT64_T chirp_reli_flush( struct chirp_file *file, time_t stoptime );

INT64_T chirp_reli_getfile( const char *host, const char *path, FILE *stream, time_t stoptime );
INT64_T chirp_reli_getfile_buffer( const char *host, const char *path, char **buffer, time_t stoptime );
INT64_T chirp_reli_putfile( const char *host, const char *path, FILE *stream, INT64_T mode, INT64_T length, time_t stoptime );
INT64_T chirp_reli_putfile_buffer( const char *host, const char *path, const char *buffer, INT64_T mode, INT64_T length, time_t stoptime );
INT64_T chirp_reli_getlongdir( const char *host, const char *path, chirp_longdir_t callback, void *arg, time_t stoptime );
INT64_T chirp_reli_getdir( const char *host, const char *path, chirp_dir_t callback, void *arg, time_t stoptime );
INT64_T chirp_reli_getacl( const char *host, const char *path, chirp_dir_t callback, void *arg, time_t stoptime );
INT64_T chirp_reli_setacl( const char *host, const char *path, const char *subject, const char *rights, time_t stoptime );
INT64_T chirp_reli_whoami( const char *host, char *buf, INT64_T length, time_t stoptime );
INT64_T chirp_reli_whoareyou( const char *host, const char *rhost, char *buffer, INT64_T length, time_t stoptime  );
INT64_T chirp_reli_unlink( const char *host, const char *path, time_t stoptime );
INT64_T chirp_reli_rename( const char *host, const char *path, const char *newpath, time_t stoptime );
INT64_T chirp_reli_link( const char *host, const char *path, const char *newpath, time_t stoptime );
INT64_T chirp_reli_symlink( const char *host, const char *path, const char *newpath, time_t stoptime );
INT64_T chirp_reli_readlink( const char *host, const char *path, char *buf, INT64_T length, time_t stoptime );
INT64_T chirp_reli_lsalloc( const char *host, const char *path, char *allocpath, INT64_T *total, INT64_T *inuse, time_t stoptime );
INT64_T chirp_reli_mkdir( const char *host, const char *path, INT64_T mode, time_t stoptime );
INT64_T chirp_reli_rmdir( const char *host, const char *path, time_t stoptime );
INT64_T chirp_reli_rmall( const char *host, const char *path, time_t stoptime );
INT64_T chirp_reli_stat( const char *host, const char *path, struct chirp_stat *buf, time_t stoptime );
INT64_T chirp_reli_lstat( const char *host, const char *path, struct chirp_stat *buf, time_t stoptime );
INT64_T chirp_reli_statfs( const char *host, const char *path, struct chirp_statfs *buf, time_t stoptime );
INT64_T chirp_reli_access( const char *host, const char *path, INT64_T mode, time_t stoptime );
INT64_T chirp_reli_chmod( const char *host, const char *path, INT64_T mode, time_t stoptime );
INT64_T chirp_reli_chown( const char *host, const char *path, INT64_T uid, INT64_T gid, time_t stoptime );
INT64_T chirp_reli_lchown( const char *host, const char *path, INT64_T uid, INT64_T gid, time_t stoptime );
INT64_T chirp_reli_truncate( const char *host, const char *path, INT64_T length, time_t stoptime );
INT64_T chirp_reli_utime( const char *host, const char *path, time_t actime, time_t modtime, time_t stoptime );
INT64_T chirp_reli_md5( const char *host, const char *path, unsigned char digest[16], time_t stoptime );
INT64_T chirp_reli_audit( const char *host, const char *path, struct chirp_audit **list, time_t stoptime );
INT64_T chirp_reli_exec( const char *host, const char *infile, const char *outfile, const char *errfile, const char *cmd, time_t stoptime );
INT64_T chirp_reli_thirdput( const char *host, const char *path, const char *thirdhost, const char *thirdpath, time_t stoptime );

INT64_T chirp_reli_mkalloc( const char *host, const char *path, INT64_T size, INT64_T mode, time_t stoptime );
INT64_T chirp_reli_lsalloc( const char *host, const char *path, char *alloc_path, INT64_T *size, INT64_T *inuse , time_t stoptime );

INT64_T chirp_reli_blocksize_get();
void    chirp_reli_blocksize_set( INT64_T bs );

INT64_T chirp_reli_group_create( const char *host, char *group, time_t stoptime );
INT64_T chirp_reli_group_list( const char *host, const char *group, chirp_dir_t callback, void *arg, time_t stoptime );
INT64_T chirp_reli_group_add( const char *host, char *group, char *user, time_t stoptime );
INT64_T chirp_reli_group_remove( const char *host, char *group, char *user, time_t stoptime );
INT64_T chirp_reli_group_lookup( const char *host, const char *group, const char *user, time_t stoptime );
INT64_T chirp_reli_group_cache_update( const char *host, const char *group, time_t mod_time, time_t stoptime );
INT64_T chirp_reli_group_policy_set( const char *host, char *group, unsigned long int file_duration, unsigned long int dec_duration, time_t stoptime );
INT64_T chirp_reli_group_policy_get( const char *host, const char *group, int *policy, int *file_duration, int *dec_duration, time_t stoptime );

INT64_T chirp_reli_job_begin( const char *host, const char *cwd, const char *input, const char *output, const char *error, const char *cmdline, time_t stoptime );
INT64_T chirp_reli_job_commit( const char *host, INT64_T jobid, time_t stoptime );
INT64_T chirp_reli_job_wait( const char *host, INT64_T jobid, struct chirp_job_state *state, int wait_time, time_t stoptime );
INT64_T chirp_reli_job_kill( const char *host, INT64_T jobid, time_t stoptime );
INT64_T chirp_reli_job_remove( const char *host, INT64_T jobid, time_t stoptime );
INT64_T chirp_reli_job_list( const char *host, chirp_joblist_t callback, void *arg, time_t stoptime );

#endif
