/*
Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
Copyright (C) 2005- The University of Notre Dame
This software is distributed under a BSD-style license.
See the file COPYING for details.
*/
#ifndef NVPAIR_H
#define NVPAIR_H

#include <stdio.h>
#include "int_sizes.h"

/*
An nvpair object is a collection of name-value pairs that might
describe a complex object such as a host or a job.  An nvpair object
is a subset of the full generality of an XML document or a ClassAd.
In fact, and nvpair can easily be exported into these and other formats.
We use an nvapir object instead of these other database, because it
has a dramatically simpler implementation that these other complex datatypes
and removes any dependence on external software.
*/

struct nvpair * nvpair_create();
void            nvpair_delete( struct nvpair *n );

void		nvpair_parse( struct nvpair *n, const char *text );
int             nvpair_print( struct nvpair *n, char *text, int length );
int		nvpair_print_alloc( struct nvpair *n, char **text );

void            nvpair_insert_string( struct nvpair *n, const char *name, const char *value );
void            nvpair_insert_integer( struct nvpair *n, const char *name, INT64_T value );
const char *    nvpair_lookup_string( struct nvpair *n, const char *name );
INT64_T         nvpair_lookup_integer( struct nvpair *n, const char *name );

typedef enum {
	NVPAIR_MODE_STRING,
	NVPAIR_MODE_INTEGER,
	NVPAIR_MODE_URL,
	NVPAIR_MODE_METRIC
} nvpair_mode_t;

typedef enum {
	NVPAIR_ALIGN_LEFT,
	NVPAIR_ALIGN_RIGHT
} nvpair_align_t;

struct nvpair_header {
	const char *name;
	nvpair_mode_t mode;
	nvpair_align_t align;
	int width;
};

void nvpair_print_text( struct nvpair *n, FILE *stream );
void nvpair_print_xml( struct nvpair *n, FILE *stream );
void nvpair_print_new_classads( struct nvpair *n, FILE *stream );
void nvpair_print_old_classads( struct nvpair *n, FILE *stream );
void nvpair_print_html_solo( struct nvpair *n, FILE *stream );

void nvpair_print_html_header( FILE *stream, struct nvpair_header *h );
void nvpair_print_html( struct nvpair *n, FILE *stream, struct nvpair_header *h );
void nvpair_print_html_with_link( struct nvpair *n, FILE *stream, struct nvpair_header *h, const char *linkname, const char *linktext );

void nvpair_print_html_footer( FILE *stream, struct nvpair_header *h );

void nvpair_print_table_header( FILE *stream, struct nvpair_header *h );
void nvpair_print_table( struct nvpair *n, FILE *stream, struct nvpair_header *h );
void nvpair_print_table_footer( FILE *stream, struct nvpair_header *h );

#endif
